@@ -192,6 +192,7 @@ class Chatbot(object):
                                 role: str = "",
                                 optimizer: Optimizer = None,
                                 web_enhance_server: dict = None,
+                                no_penalty: bool = False,
                                 **kwargs
                                 ) -> dict:
         """
@@ -204,13 +205,14 @@ class Chatbot(object):
         :param prompt: 提示词
         :param optimizer: 优化器
         :param character: 性格提示词，列表字符串
+        :param no_penalty: 不使用自动惩罚参数调整
         :return:
         """
         prompt = prompt.replace("帮我", "给我").replace("Help me", "Give me")
 
         # OPTIMIZER
         if optimizer is None:
-            optimizer = Optimizer.MatrixPoint
+            optimizer = Optimizer.SinglePoint
 
         # LANG
         prompt_lang = Detect.get_text_language(sentence=prompt)
@@ -276,19 +278,25 @@ class Chatbot(object):
         while Utils.tokenizer(_prompt) > _mk:
             _prompt = _prompt[1:]
         _prompt = _header + _prompt
-
-        # THINK ABOUT HOT CAKE
-        _frequency_penalty, _presence_penalty, _temperature = Detect().get_tendency_arg(prompt=prompt)
-
-        # SOME HOT CAKE
-        api_config = {
-            "frequency_penalty": _frequency_penalty,
-            "presence_penalty": _presence_penalty,
-            "temperature": _temperature,
+        _request_arg = {
+            "temperature": 0.9,
             "logit_bias": {}
         }
-        config = {key: item for key, item in kwargs.items() if key in api_config.keys()}
-        api_config.update(config)
+        if not no_penalty:
+            # THINK ABOUT HOT CAKE
+            _frequency_penalty, _presence_penalty, _temperature = Detect().get_tendency_arg(prompt=prompt)
+            # SOME HOT CAKE
+            _request_arg.update({
+                "frequency_penalty": _frequency_penalty,
+                "presence_penalty": _presence_penalty,
+                "temperature": _temperature,
+                "logit_bias": {}
+            })
+
+        # KWARGS
+        _arg_config = {key: item for key, item in kwargs.items() if key in _request_arg.keys()}
+        _request_arg.update(_arg_config)
+
         # REQ
         response = await Completion(api_key=self.__api_key, call_func=self.__call_func).create(
             model=model,
@@ -301,7 +309,7 @@ class Chatbot(object):
                   f"{self._restart_sequence}:",
                   f"{self._start_sequence}：",
                   f"{self._restart_sequence}："],
-            **api_config
+            **_request_arg
         )
         self.record_dialogue(prompt=prompt, response=response)
         return response
@@ -317,7 +325,7 @@ class Chatbot(object):
             processed = await processor.process(param=PluginParam(text=prompt, server=table), plugins=[plugin])
             _return.extend(processed)
         reply = "\n".join(_return) if _return else ""
-        reply = reply[:700]
+        reply = reply[:500]
         logger.debug(f"AllPluginReturn:{reply}")
         return reply
 
