@@ -3,8 +3,8 @@
 # @FileName: Utils.py
 # @Software: PyCharm
 # @Github    ：sudoskys
-import random
 import re
+import random
 
 from .langdetect.langdetect import LangDetector
 from ..Chat.text_analysis_tools.api.keywords.tfidf import TfidfKeywords
@@ -75,10 +75,14 @@ class Detect(object):
         return code
 
     @staticmethod
-    def get_text_language(sentence: str, raw_list: bool = False):
-        if raw_list:
-            return LangDetector().detect(sentence)
-        return LangDetector().detect(sentence)[0][0].upper()
+    def get_text_language(sentence: str):
+        try:
+            from .fatlangdetect import detect
+            lang_type = detect(text=sentence.replace("\n", "").replace("\r", ""), low_memory=True).get("lang").upper()
+        except Exception as e:
+            from .langdetect import detect
+            lang_type = detect(text=sentence.replace("\n", "").replace("\r", ""))[0][0].upper()
+        return lang_type
 
     def get_tendency_arg(self, prompt: str, memory: list = None, lang: str = "CN") -> tuple:
         if memory is None:
@@ -120,18 +124,19 @@ class Detect(object):
             if _memory_len / 20 > 0.7:
                 frequency_penalty = abs(frequency_penalty)
 
-        # CHECK
-        temperature = temperature if 0 < temperature <= 1 else 0.9
-
-        presence_penalty = presence_penalty if -2.0 < presence_penalty else -1.5
-        presence_penalty = presence_penalty if presence_penalty < 2.0 else 1.5
-
-        frequency_penalty = frequency_penalty if -2.0 < frequency_penalty else -1.5
-        frequency_penalty = frequency_penalty if frequency_penalty < 2.0 else 1.5
-
+        # FIX
         temperature = round(temperature, 1)
         presence_penalty = round(presence_penalty, 1)
         frequency_penalty = round(frequency_penalty, 1)
+
+        # CHECK
+        temperature = temperature if 0 < temperature < 1 else 0.9
+
+        presence_penalty = presence_penalty if -2.0 < presence_penalty else -0.1
+        presence_penalty = presence_penalty if presence_penalty < 2.0 else 0.1
+
+        frequency_penalty = frequency_penalty if -2.0 < frequency_penalty else -0.1
+        frequency_penalty = frequency_penalty if frequency_penalty < 2.0 else 0.1
         return frequency_penalty, presence_penalty, temperature
 
 
